pplitepy: Python pplite wrapper
===============================

Description
-----------

Python pplite wrapper

License
-------

GPL v3

Upstream Contact
----------------

https://pypi.org/project/pplitepy/

